# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ExpressRouteAuthorizationArgs', 'ExpressRouteAuthorization']

@pulumi.input_type
class ExpressRouteAuthorizationArgs:
    def __init__(__self__, *,
                 private_cloud_id: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ExpressRouteAuthorization resource.
        :param pulumi.Input[str] private_cloud_id: The ID of the Azure VMware Solution Private Cloud in which to create this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        :param pulumi.Input[str] name: The name which should be used for this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        pulumi.set(__self__, "private_cloud_id", private_cloud_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="privateCloudId")
    def private_cloud_id(self) -> pulumi.Input[str]:
        """
        The ID of the Azure VMware Solution Private Cloud in which to create this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        return pulumi.get(self, "private_cloud_id")

    @private_cloud_id.setter
    def private_cloud_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "private_cloud_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ExpressRouteAuthorizationState:
    def __init__(__self__, *,
                 express_route_authorization_id: Optional[pulumi.Input[str]] = None,
                 express_route_authorization_key: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 private_cloud_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ExpressRouteAuthorization resources.
        :param pulumi.Input[str] express_route_authorization_id: The ID of the Azure VMware Solution ExpressRoute Circuit Authorization.
        :param pulumi.Input[str] express_route_authorization_key: The key of the Azure VMware Solution ExpressRoute Circuit Authorization.
        :param pulumi.Input[str] name: The name which should be used for this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        :param pulumi.Input[str] private_cloud_id: The ID of the Azure VMware Solution Private Cloud in which to create this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        if express_route_authorization_id is not None:
            pulumi.set(__self__, "express_route_authorization_id", express_route_authorization_id)
        if express_route_authorization_key is not None:
            pulumi.set(__self__, "express_route_authorization_key", express_route_authorization_key)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if private_cloud_id is not None:
            pulumi.set(__self__, "private_cloud_id", private_cloud_id)

    @property
    @pulumi.getter(name="expressRouteAuthorizationId")
    def express_route_authorization_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Azure VMware Solution ExpressRoute Circuit Authorization.
        """
        return pulumi.get(self, "express_route_authorization_id")

    @express_route_authorization_id.setter
    def express_route_authorization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "express_route_authorization_id", value)

    @property
    @pulumi.getter(name="expressRouteAuthorizationKey")
    def express_route_authorization_key(self) -> Optional[pulumi.Input[str]]:
        """
        The key of the Azure VMware Solution ExpressRoute Circuit Authorization.
        """
        return pulumi.get(self, "express_route_authorization_key")

    @express_route_authorization_key.setter
    def express_route_authorization_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "express_route_authorization_key", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="privateCloudId")
    def private_cloud_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Azure VMware Solution Private Cloud in which to create this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        return pulumi.get(self, "private_cloud_id")

    @private_cloud_id.setter
    def private_cloud_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_cloud_id", value)


class ExpressRouteAuthorization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 private_cloud_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages an Azure VMware Solution ExpressRoute Circuit Authorization.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_private_cloud = azure.avs.PrivateCloud("example",
            name="example-vmware-private-cloud",
            resource_group_name=example.name,
            location=example.location,
            sku_name="av36",
            management_cluster={
                "size": 3,
            },
            network_subnet_cidr="192.168.48.0/22",
            internet_connection_enabled=False,
            nsxt_password="QazWsx13$Edc",
            vcenter_password="WsxEdc23$Rfv")
        example_express_route_authorization = azure.avs.ExpressRouteAuthorization("example",
            name="example-authorization",
            private_cloud_id=example_private_cloud.id)
        ```

        ## Import

        Azure VMware Solution ExpressRoute Circuit Authorizations can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:avs/expressRouteAuthorization:ExpressRouteAuthorization example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.AVS/privateClouds/privateCloud1/authorizations/authorization1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name which should be used for this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        :param pulumi.Input[str] private_cloud_id: The ID of the Azure VMware Solution Private Cloud in which to create this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ExpressRouteAuthorizationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an Azure VMware Solution ExpressRoute Circuit Authorization.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_private_cloud = azure.avs.PrivateCloud("example",
            name="example-vmware-private-cloud",
            resource_group_name=example.name,
            location=example.location,
            sku_name="av36",
            management_cluster={
                "size": 3,
            },
            network_subnet_cidr="192.168.48.0/22",
            internet_connection_enabled=False,
            nsxt_password="QazWsx13$Edc",
            vcenter_password="WsxEdc23$Rfv")
        example_express_route_authorization = azure.avs.ExpressRouteAuthorization("example",
            name="example-authorization",
            private_cloud_id=example_private_cloud.id)
        ```

        ## Import

        Azure VMware Solution ExpressRoute Circuit Authorizations can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:avs/expressRouteAuthorization:ExpressRouteAuthorization example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.AVS/privateClouds/privateCloud1/authorizations/authorization1
        ```

        :param str resource_name: The name of the resource.
        :param ExpressRouteAuthorizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ExpressRouteAuthorizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 private_cloud_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ExpressRouteAuthorizationArgs.__new__(ExpressRouteAuthorizationArgs)

            __props__.__dict__["name"] = name
            if private_cloud_id is None and not opts.urn:
                raise TypeError("Missing required property 'private_cloud_id'")
            __props__.__dict__["private_cloud_id"] = private_cloud_id
            __props__.__dict__["express_route_authorization_id"] = None
            __props__.__dict__["express_route_authorization_key"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["expressRouteAuthorizationKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ExpressRouteAuthorization, __self__).__init__(
            'azure:avs/expressRouteAuthorization:ExpressRouteAuthorization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            express_route_authorization_id: Optional[pulumi.Input[str]] = None,
            express_route_authorization_key: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            private_cloud_id: Optional[pulumi.Input[str]] = None) -> 'ExpressRouteAuthorization':
        """
        Get an existing ExpressRouteAuthorization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] express_route_authorization_id: The ID of the Azure VMware Solution ExpressRoute Circuit Authorization.
        :param pulumi.Input[str] express_route_authorization_key: The key of the Azure VMware Solution ExpressRoute Circuit Authorization.
        :param pulumi.Input[str] name: The name which should be used for this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        :param pulumi.Input[str] private_cloud_id: The ID of the Azure VMware Solution Private Cloud in which to create this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ExpressRouteAuthorizationState.__new__(_ExpressRouteAuthorizationState)

        __props__.__dict__["express_route_authorization_id"] = express_route_authorization_id
        __props__.__dict__["express_route_authorization_key"] = express_route_authorization_key
        __props__.__dict__["name"] = name
        __props__.__dict__["private_cloud_id"] = private_cloud_id
        return ExpressRouteAuthorization(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="expressRouteAuthorizationId")
    def express_route_authorization_id(self) -> pulumi.Output[str]:
        """
        The ID of the Azure VMware Solution ExpressRoute Circuit Authorization.
        """
        return pulumi.get(self, "express_route_authorization_id")

    @property
    @pulumi.getter(name="expressRouteAuthorizationKey")
    def express_route_authorization_key(self) -> pulumi.Output[str]:
        """
        The key of the Azure VMware Solution ExpressRoute Circuit Authorization.
        """
        return pulumi.get(self, "express_route_authorization_key")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="privateCloudId")
    def private_cloud_id(self) -> pulumi.Output[str]:
        """
        The ID of the Azure VMware Solution Private Cloud in which to create this Azure VMware Solution ExpressRoute Circuit Authorization. Changing this forces a new Azure VMware Solution ExpressRoute Circuit Authorization to be created.
        """
        return pulumi.get(self, "private_cloud_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'CollectorPolicyIpfxEmission',
    'CollectorPolicyIpfxIngestion',
]

@pulumi.output_type
class CollectorPolicyIpfxEmission(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationTypes":
            suggest = "destination_types"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CollectorPolicyIpfxEmission. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CollectorPolicyIpfxEmission.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CollectorPolicyIpfxEmission.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_types: str):
        """
        :param str destination_types: A list of emission destination types. The only possible value is `AzureMonitor`. Changing this forces a new Network Function Collector Policy to be created.
        """
        pulumi.set(__self__, "destination_types", destination_types)

    @property
    @pulumi.getter(name="destinationTypes")
    def destination_types(self) -> str:
        """
        A list of emission destination types. The only possible value is `AzureMonitor`. Changing this forces a new Network Function Collector Policy to be created.
        """
        return pulumi.get(self, "destination_types")


@pulumi.output_type
class CollectorPolicyIpfxIngestion(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "sourceResourceIds":
            suggest = "source_resource_ids"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CollectorPolicyIpfxIngestion. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CollectorPolicyIpfxIngestion.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CollectorPolicyIpfxIngestion.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 source_resource_ids: Sequence[str]):
        """
        :param Sequence[str] source_resource_ids: A list of ingestion source resource IDs. Changing this forces a new Network Function Collector Policy to be created.
        """
        pulumi.set(__self__, "source_resource_ids", source_resource_ids)

    @property
    @pulumi.getter(name="sourceResourceIds")
    def source_resource_ids(self) -> Sequence[str]:
        """
        A list of ingestion source resource IDs. Changing this forces a new Network Function Collector Policy to be created.
        """
        return pulumi.get(self, "source_resource_ids")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ReferenceInputMssqlArgs', 'ReferenceInputMssql']

@pulumi.input_type
class ReferenceInputMssqlArgs:
    def __init__(__self__, *,
                 database: pulumi.Input[str],
                 full_snapshot_query: pulumi.Input[str],
                 password: pulumi.Input[str],
                 refresh_type: pulumi.Input[str],
                 resource_group_name: pulumi.Input[str],
                 server: pulumi.Input[str],
                 stream_analytics_job_name: pulumi.Input[str],
                 username: pulumi.Input[str],
                 delta_snapshot_query: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 refresh_interval_duration: Optional[pulumi.Input[str]] = None,
                 table: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ReferenceInputMssql resource.
        :param pulumi.Input[str] database: The MS SQL database name where the reference data exists.
        :param pulumi.Input[str] full_snapshot_query: The query used to retrieve the reference data from the MS SQL database.
        :param pulumi.Input[str] password: The password to connect to the MS SQL database.
        :param pulumi.Input[str] refresh_type: Defines whether and how the reference data should be refreshed. Accepted values are `Static`, `RefreshPeriodicallyWithFull` and `RefreshPeriodicallyWithDelta`.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Stream Analytics Job should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] server: The fully qualified domain name of the MS SQL server.
        :param pulumi.Input[str] stream_analytics_job_name: The name of the Stream Analytics Job. Changing this forces a new resource to be created.
        :param pulumi.Input[str] username: The username to connect to the MS SQL database.
        :param pulumi.Input[str] delta_snapshot_query: The query used to retrieve incremental changes in the reference data from the MS SQL database. Cannot be set when `refresh_type` is `Static`.
        :param pulumi.Input[str] name: The name of the Reference Input MS SQL data. Changing this forces a new resource to be created.
        :param pulumi.Input[str] refresh_interval_duration: The frequency in `hh:mm:ss` with which the reference data should be retrieved from the MS SQL database e.g. `00:20:00` for every 20 minutes. Must be set when `refresh_type` is `RefreshPeriodicallyWithFull` or `RefreshPeriodicallyWithDelta`.
        :param pulumi.Input[str] table: The name of the table in the Azure SQL database.
        """
        pulumi.set(__self__, "database", database)
        pulumi.set(__self__, "full_snapshot_query", full_snapshot_query)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "refresh_type", refresh_type)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "server", server)
        pulumi.set(__self__, "stream_analytics_job_name", stream_analytics_job_name)
        pulumi.set(__self__, "username", username)
        if delta_snapshot_query is not None:
            pulumi.set(__self__, "delta_snapshot_query", delta_snapshot_query)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if refresh_interval_duration is not None:
            pulumi.set(__self__, "refresh_interval_duration", refresh_interval_duration)
        if table is not None:
            pulumi.set(__self__, "table", table)

    @property
    @pulumi.getter
    def database(self) -> pulumi.Input[str]:
        """
        The MS SQL database name where the reference data exists.
        """
        return pulumi.get(self, "database")

    @database.setter
    def database(self, value: pulumi.Input[str]):
        pulumi.set(self, "database", value)

    @property
    @pulumi.getter(name="fullSnapshotQuery")
    def full_snapshot_query(self) -> pulumi.Input[str]:
        """
        The query used to retrieve the reference data from the MS SQL database.
        """
        return pulumi.get(self, "full_snapshot_query")

    @full_snapshot_query.setter
    def full_snapshot_query(self, value: pulumi.Input[str]):
        pulumi.set(self, "full_snapshot_query", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[str]:
        """
        The password to connect to the MS SQL database.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="refreshType")
    def refresh_type(self) -> pulumi.Input[str]:
        """
        Defines whether and how the reference data should be refreshed. Accepted values are `Static`, `RefreshPeriodicallyWithFull` and `RefreshPeriodicallyWithDelta`.
        """
        return pulumi.get(self, "refresh_type")

    @refresh_type.setter
    def refresh_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "refresh_type", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the Resource Group where the Stream Analytics Job should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def server(self) -> pulumi.Input[str]:
        """
        The fully qualified domain name of the MS SQL server.
        """
        return pulumi.get(self, "server")

    @server.setter
    def server(self, value: pulumi.Input[str]):
        pulumi.set(self, "server", value)

    @property
    @pulumi.getter(name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> pulumi.Input[str]:
        """
        The name of the Stream Analytics Job. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "stream_analytics_job_name")

    @stream_analytics_job_name.setter
    def stream_analytics_job_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "stream_analytics_job_name", value)

    @property
    @pulumi.getter
    def username(self) -> pulumi.Input[str]:
        """
        The username to connect to the MS SQL database.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[str]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="deltaSnapshotQuery")
    def delta_snapshot_query(self) -> Optional[pulumi.Input[str]]:
        """
        The query used to retrieve incremental changes in the reference data from the MS SQL database. Cannot be set when `refresh_type` is `Static`.
        """
        return pulumi.get(self, "delta_snapshot_query")

    @delta_snapshot_query.setter
    def delta_snapshot_query(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delta_snapshot_query", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Reference Input MS SQL data. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="refreshIntervalDuration")
    def refresh_interval_duration(self) -> Optional[pulumi.Input[str]]:
        """
        The frequency in `hh:mm:ss` with which the reference data should be retrieved from the MS SQL database e.g. `00:20:00` for every 20 minutes. Must be set when `refresh_type` is `RefreshPeriodicallyWithFull` or `RefreshPeriodicallyWithDelta`.
        """
        return pulumi.get(self, "refresh_interval_duration")

    @refresh_interval_duration.setter
    def refresh_interval_duration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "refresh_interval_duration", value)

    @property
    @pulumi.getter
    def table(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the table in the Azure SQL database.
        """
        return pulumi.get(self, "table")

    @table.setter
    def table(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "table", value)


@pulumi.input_type
class _ReferenceInputMssqlState:
    def __init__(__self__, *,
                 database: Optional[pulumi.Input[str]] = None,
                 delta_snapshot_query: Optional[pulumi.Input[str]] = None,
                 full_snapshot_query: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 refresh_interval_duration: Optional[pulumi.Input[str]] = None,
                 refresh_type: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 server: Optional[pulumi.Input[str]] = None,
                 stream_analytics_job_name: Optional[pulumi.Input[str]] = None,
                 table: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ReferenceInputMssql resources.
        :param pulumi.Input[str] database: The MS SQL database name where the reference data exists.
        :param pulumi.Input[str] delta_snapshot_query: The query used to retrieve incremental changes in the reference data from the MS SQL database. Cannot be set when `refresh_type` is `Static`.
        :param pulumi.Input[str] full_snapshot_query: The query used to retrieve the reference data from the MS SQL database.
        :param pulumi.Input[str] name: The name of the Reference Input MS SQL data. Changing this forces a new resource to be created.
        :param pulumi.Input[str] password: The password to connect to the MS SQL database.
        :param pulumi.Input[str] refresh_interval_duration: The frequency in `hh:mm:ss` with which the reference data should be retrieved from the MS SQL database e.g. `00:20:00` for every 20 minutes. Must be set when `refresh_type` is `RefreshPeriodicallyWithFull` or `RefreshPeriodicallyWithDelta`.
        :param pulumi.Input[str] refresh_type: Defines whether and how the reference data should be refreshed. Accepted values are `Static`, `RefreshPeriodicallyWithFull` and `RefreshPeriodicallyWithDelta`.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Stream Analytics Job should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] server: The fully qualified domain name of the MS SQL server.
        :param pulumi.Input[str] stream_analytics_job_name: The name of the Stream Analytics Job. Changing this forces a new resource to be created.
        :param pulumi.Input[str] table: The name of the table in the Azure SQL database.
        :param pulumi.Input[str] username: The username to connect to the MS SQL database.
        """
        if database is not None:
            pulumi.set(__self__, "database", database)
        if delta_snapshot_query is not None:
            pulumi.set(__self__, "delta_snapshot_query", delta_snapshot_query)
        if full_snapshot_query is not None:
            pulumi.set(__self__, "full_snapshot_query", full_snapshot_query)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if refresh_interval_duration is not None:
            pulumi.set(__self__, "refresh_interval_duration", refresh_interval_duration)
        if refresh_type is not None:
            pulumi.set(__self__, "refresh_type", refresh_type)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if server is not None:
            pulumi.set(__self__, "server", server)
        if stream_analytics_job_name is not None:
            pulumi.set(__self__, "stream_analytics_job_name", stream_analytics_job_name)
        if table is not None:
            pulumi.set(__self__, "table", table)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def database(self) -> Optional[pulumi.Input[str]]:
        """
        The MS SQL database name where the reference data exists.
        """
        return pulumi.get(self, "database")

    @database.setter
    def database(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database", value)

    @property
    @pulumi.getter(name="deltaSnapshotQuery")
    def delta_snapshot_query(self) -> Optional[pulumi.Input[str]]:
        """
        The query used to retrieve incremental changes in the reference data from the MS SQL database. Cannot be set when `refresh_type` is `Static`.
        """
        return pulumi.get(self, "delta_snapshot_query")

    @delta_snapshot_query.setter
    def delta_snapshot_query(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delta_snapshot_query", value)

    @property
    @pulumi.getter(name="fullSnapshotQuery")
    def full_snapshot_query(self) -> Optional[pulumi.Input[str]]:
        """
        The query used to retrieve the reference data from the MS SQL database.
        """
        return pulumi.get(self, "full_snapshot_query")

    @full_snapshot_query.setter
    def full_snapshot_query(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "full_snapshot_query", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Reference Input MS SQL data. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password to connect to the MS SQL database.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="refreshIntervalDuration")
    def refresh_interval_duration(self) -> Optional[pulumi.Input[str]]:
        """
        The frequency in `hh:mm:ss` with which the reference data should be retrieved from the MS SQL database e.g. `00:20:00` for every 20 minutes. Must be set when `refresh_type` is `RefreshPeriodicallyWithFull` or `RefreshPeriodicallyWithDelta`.
        """
        return pulumi.get(self, "refresh_interval_duration")

    @refresh_interval_duration.setter
    def refresh_interval_duration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "refresh_interval_duration", value)

    @property
    @pulumi.getter(name="refreshType")
    def refresh_type(self) -> Optional[pulumi.Input[str]]:
        """
        Defines whether and how the reference data should be refreshed. Accepted values are `Static`, `RefreshPeriodicallyWithFull` and `RefreshPeriodicallyWithDelta`.
        """
        return pulumi.get(self, "refresh_type")

    @refresh_type.setter
    def refresh_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "refresh_type", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Resource Group where the Stream Analytics Job should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def server(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified domain name of the MS SQL server.
        """
        return pulumi.get(self, "server")

    @server.setter
    def server(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "server", value)

    @property
    @pulumi.getter(name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Stream Analytics Job. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "stream_analytics_job_name")

    @stream_analytics_job_name.setter
    def stream_analytics_job_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stream_analytics_job_name", value)

    @property
    @pulumi.getter
    def table(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the table in the Azure SQL database.
        """
        return pulumi.get(self, "table")

    @table.setter
    def table(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "table", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        The username to connect to the MS SQL database.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class ReferenceInputMssql(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database: Optional[pulumi.Input[str]] = None,
                 delta_snapshot_query: Optional[pulumi.Input[str]] = None,
                 full_snapshot_query: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 refresh_interval_duration: Optional[pulumi.Input[str]] = None,
                 refresh_type: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 server: Optional[pulumi.Input[str]] = None,
                 stream_analytics_job_name: Optional[pulumi.Input[str]] = None,
                 table: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Stream Analytics Reference Input from MS SQL. Reference data (also known as a lookup table) is a finite data set that is static or slowly changing in nature, used to perform a lookup or to correlate with your data stream. Learn more [here](https://docs.microsoft.com/azure/stream-analytics/stream-analytics-use-reference-data#azure-sql-database).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example = azure.streamanalytics.get_job_output(name="example-job",
            resource_group_name=example_resource_group.name)
        example_server = azure.mssql.Server("example",
            name="example-sqlserver",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            version="12.0",
            administrator_login="admin",
            administrator_login_password="password")
        example_database = azure.mssql.Database("example",
            name="example-db",
            server_id=example_server.id)
        example_reference_input_mssql = azure.streamanalytics.ReferenceInputMssql("example",
            name="example-reference-input",
            resource_group_name=example.resource_group_name,
            stream_analytics_job_name=example.name,
            server=example_server.fully_qualified_domain_name,
            database=example_database.name,
            username="exampleuser",
            password="examplepassword",
            refresh_type="RefreshPeriodicallyWithFull",
            refresh_interval_duration="00:20:00",
            full_snapshot_query=\"\"\"    SELECT *
            INTO [YourOutputAlias]
            FROM [YourInputAlias]
        \"\"\")
        ```

        ## Import

        Stream Analytics can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:streamanalytics/referenceInputMssql:ReferenceInputMssql example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.StreamAnalytics/streamingJobs/job1/inputs/input1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] database: The MS SQL database name where the reference data exists.
        :param pulumi.Input[str] delta_snapshot_query: The query used to retrieve incremental changes in the reference data from the MS SQL database. Cannot be set when `refresh_type` is `Static`.
        :param pulumi.Input[str] full_snapshot_query: The query used to retrieve the reference data from the MS SQL database.
        :param pulumi.Input[str] name: The name of the Reference Input MS SQL data. Changing this forces a new resource to be created.
        :param pulumi.Input[str] password: The password to connect to the MS SQL database.
        :param pulumi.Input[str] refresh_interval_duration: The frequency in `hh:mm:ss` with which the reference data should be retrieved from the MS SQL database e.g. `00:20:00` for every 20 minutes. Must be set when `refresh_type` is `RefreshPeriodicallyWithFull` or `RefreshPeriodicallyWithDelta`.
        :param pulumi.Input[str] refresh_type: Defines whether and how the reference data should be refreshed. Accepted values are `Static`, `RefreshPeriodicallyWithFull` and `RefreshPeriodicallyWithDelta`.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Stream Analytics Job should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] server: The fully qualified domain name of the MS SQL server.
        :param pulumi.Input[str] stream_analytics_job_name: The name of the Stream Analytics Job. Changing this forces a new resource to be created.
        :param pulumi.Input[str] table: The name of the table in the Azure SQL database.
        :param pulumi.Input[str] username: The username to connect to the MS SQL database.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ReferenceInputMssqlArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Stream Analytics Reference Input from MS SQL. Reference data (also known as a lookup table) is a finite data set that is static or slowly changing in nature, used to perform a lookup or to correlate with your data stream. Learn more [here](https://docs.microsoft.com/azure/stream-analytics/stream-analytics-use-reference-data#azure-sql-database).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example = azure.streamanalytics.get_job_output(name="example-job",
            resource_group_name=example_resource_group.name)
        example_server = azure.mssql.Server("example",
            name="example-sqlserver",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            version="12.0",
            administrator_login="admin",
            administrator_login_password="password")
        example_database = azure.mssql.Database("example",
            name="example-db",
            server_id=example_server.id)
        example_reference_input_mssql = azure.streamanalytics.ReferenceInputMssql("example",
            name="example-reference-input",
            resource_group_name=example.resource_group_name,
            stream_analytics_job_name=example.name,
            server=example_server.fully_qualified_domain_name,
            database=example_database.name,
            username="exampleuser",
            password="examplepassword",
            refresh_type="RefreshPeriodicallyWithFull",
            refresh_interval_duration="00:20:00",
            full_snapshot_query=\"\"\"    SELECT *
            INTO [YourOutputAlias]
            FROM [YourInputAlias]
        \"\"\")
        ```

        ## Import

        Stream Analytics can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:streamanalytics/referenceInputMssql:ReferenceInputMssql example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.StreamAnalytics/streamingJobs/job1/inputs/input1
        ```

        :param str resource_name: The name of the resource.
        :param ReferenceInputMssqlArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ReferenceInputMssqlArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database: Optional[pulumi.Input[str]] = None,
                 delta_snapshot_query: Optional[pulumi.Input[str]] = None,
                 full_snapshot_query: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 refresh_interval_duration: Optional[pulumi.Input[str]] = None,
                 refresh_type: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 server: Optional[pulumi.Input[str]] = None,
                 stream_analytics_job_name: Optional[pulumi.Input[str]] = None,
                 table: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ReferenceInputMssqlArgs.__new__(ReferenceInputMssqlArgs)

            if database is None and not opts.urn:
                raise TypeError("Missing required property 'database'")
            __props__.__dict__["database"] = database
            __props__.__dict__["delta_snapshot_query"] = delta_snapshot_query
            if full_snapshot_query is None and not opts.urn:
                raise TypeError("Missing required property 'full_snapshot_query'")
            __props__.__dict__["full_snapshot_query"] = full_snapshot_query
            __props__.__dict__["name"] = name
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["refresh_interval_duration"] = refresh_interval_duration
            if refresh_type is None and not opts.urn:
                raise TypeError("Missing required property 'refresh_type'")
            __props__.__dict__["refresh_type"] = refresh_type
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if server is None and not opts.urn:
                raise TypeError("Missing required property 'server'")
            __props__.__dict__["server"] = server
            if stream_analytics_job_name is None and not opts.urn:
                raise TypeError("Missing required property 'stream_analytics_job_name'")
            __props__.__dict__["stream_analytics_job_name"] = stream_analytics_job_name
            __props__.__dict__["table"] = table
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ReferenceInputMssql, __self__).__init__(
            'azure:streamanalytics/referenceInputMssql:ReferenceInputMssql',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            database: Optional[pulumi.Input[str]] = None,
            delta_snapshot_query: Optional[pulumi.Input[str]] = None,
            full_snapshot_query: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            refresh_interval_duration: Optional[pulumi.Input[str]] = None,
            refresh_type: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            server: Optional[pulumi.Input[str]] = None,
            stream_analytics_job_name: Optional[pulumi.Input[str]] = None,
            table: Optional[pulumi.Input[str]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'ReferenceInputMssql':
        """
        Get an existing ReferenceInputMssql resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] database: The MS SQL database name where the reference data exists.
        :param pulumi.Input[str] delta_snapshot_query: The query used to retrieve incremental changes in the reference data from the MS SQL database. Cannot be set when `refresh_type` is `Static`.
        :param pulumi.Input[str] full_snapshot_query: The query used to retrieve the reference data from the MS SQL database.
        :param pulumi.Input[str] name: The name of the Reference Input MS SQL data. Changing this forces a new resource to be created.
        :param pulumi.Input[str] password: The password to connect to the MS SQL database.
        :param pulumi.Input[str] refresh_interval_duration: The frequency in `hh:mm:ss` with which the reference data should be retrieved from the MS SQL database e.g. `00:20:00` for every 20 minutes. Must be set when `refresh_type` is `RefreshPeriodicallyWithFull` or `RefreshPeriodicallyWithDelta`.
        :param pulumi.Input[str] refresh_type: Defines whether and how the reference data should be refreshed. Accepted values are `Static`, `RefreshPeriodicallyWithFull` and `RefreshPeriodicallyWithDelta`.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Stream Analytics Job should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] server: The fully qualified domain name of the MS SQL server.
        :param pulumi.Input[str] stream_analytics_job_name: The name of the Stream Analytics Job. Changing this forces a new resource to be created.
        :param pulumi.Input[str] table: The name of the table in the Azure SQL database.
        :param pulumi.Input[str] username: The username to connect to the MS SQL database.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ReferenceInputMssqlState.__new__(_ReferenceInputMssqlState)

        __props__.__dict__["database"] = database
        __props__.__dict__["delta_snapshot_query"] = delta_snapshot_query
        __props__.__dict__["full_snapshot_query"] = full_snapshot_query
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["refresh_interval_duration"] = refresh_interval_duration
        __props__.__dict__["refresh_type"] = refresh_type
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["server"] = server
        __props__.__dict__["stream_analytics_job_name"] = stream_analytics_job_name
        __props__.__dict__["table"] = table
        __props__.__dict__["username"] = username
        return ReferenceInputMssql(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def database(self) -> pulumi.Output[str]:
        """
        The MS SQL database name where the reference data exists.
        """
        return pulumi.get(self, "database")

    @property
    @pulumi.getter(name="deltaSnapshotQuery")
    def delta_snapshot_query(self) -> pulumi.Output[Optional[str]]:
        """
        The query used to retrieve incremental changes in the reference data from the MS SQL database. Cannot be set when `refresh_type` is `Static`.
        """
        return pulumi.get(self, "delta_snapshot_query")

    @property
    @pulumi.getter(name="fullSnapshotQuery")
    def full_snapshot_query(self) -> pulumi.Output[str]:
        """
        The query used to retrieve the reference data from the MS SQL database.
        """
        return pulumi.get(self, "full_snapshot_query")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Reference Input MS SQL data. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[str]:
        """
        The password to connect to the MS SQL database.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="refreshIntervalDuration")
    def refresh_interval_duration(self) -> pulumi.Output[Optional[str]]:
        """
        The frequency in `hh:mm:ss` with which the reference data should be retrieved from the MS SQL database e.g. `00:20:00` for every 20 minutes. Must be set when `refresh_type` is `RefreshPeriodicallyWithFull` or `RefreshPeriodicallyWithDelta`.
        """
        return pulumi.get(self, "refresh_interval_duration")

    @property
    @pulumi.getter(name="refreshType")
    def refresh_type(self) -> pulumi.Output[str]:
        """
        Defines whether and how the reference data should be refreshed. Accepted values are `Static`, `RefreshPeriodicallyWithFull` and `RefreshPeriodicallyWithDelta`.
        """
        return pulumi.get(self, "refresh_type")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the Resource Group where the Stream Analytics Job should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def server(self) -> pulumi.Output[str]:
        """
        The fully qualified domain name of the MS SQL server.
        """
        return pulumi.get(self, "server")

    @property
    @pulumi.getter(name="streamAnalyticsJobName")
    def stream_analytics_job_name(self) -> pulumi.Output[str]:
        """
        The name of the Stream Analytics Job. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "stream_analytics_job_name")

    @property
    @pulumi.getter
    def table(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the table in the Azure SQL database.
        """
        return pulumi.get(self, "table")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[str]:
        """
        The username to connect to the MS SQL database.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ConfigurationConfigFile',
    'ConfigurationProtectedFile',
    'DeploymentAutoScaleProfile',
    'DeploymentFrontendPrivate',
    'DeploymentFrontendPublic',
    'DeploymentIdentity',
    'DeploymentLoggingStorageAccount',
    'DeploymentNetworkInterface',
    'GetConfigurationConfigFileResult',
    'GetConfigurationProtectedFileResult',
    'GetDeploymentAutoScaleProfileResult',
    'GetDeploymentFrontendPrivateResult',
    'GetDeploymentFrontendPublicResult',
    'GetDeploymentIdentityResult',
    'GetDeploymentLoggingStorageAccountResult',
    'GetDeploymentNetworkInterfaceResult',
]

@pulumi.output_type
class ConfigurationConfigFile(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "virtualPath":
            suggest = "virtual_path"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationConfigFile. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationConfigFile.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationConfigFile.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 content: str,
                 virtual_path: str):
        """
        :param str content: Specifies the base-64 encoded contents of this config file.
        :param str virtual_path: Specifies the path of this config file.
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "virtual_path", virtual_path)

    @property
    @pulumi.getter
    def content(self) -> str:
        """
        Specifies the base-64 encoded contents of this config file.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="virtualPath")
    def virtual_path(self) -> str:
        """
        Specifies the path of this config file.
        """
        return pulumi.get(self, "virtual_path")


@pulumi.output_type
class ConfigurationProtectedFile(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "virtualPath":
            suggest = "virtual_path"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationProtectedFile. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationProtectedFile.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationProtectedFile.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 content: str,
                 virtual_path: str):
        """
        :param str content: Specifies the base-64 encoded contents of this config file (Sensitive).
        :param str virtual_path: Specifies the path of this config file.
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "virtual_path", virtual_path)

    @property
    @pulumi.getter
    def content(self) -> str:
        """
        Specifies the base-64 encoded contents of this config file (Sensitive).
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="virtualPath")
    def virtual_path(self) -> str:
        """
        Specifies the path of this config file.
        """
        return pulumi.get(self, "virtual_path")


@pulumi.output_type
class DeploymentAutoScaleProfile(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "maxCapacity":
            suggest = "max_capacity"
        elif key == "minCapacity":
            suggest = "min_capacity"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentAutoScaleProfile. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentAutoScaleProfile.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentAutoScaleProfile.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 max_capacity: int,
                 min_capacity: int,
                 name: str):
        """
        :param int min_capacity: Specify the minimum number of NGINX capacity units for this NGINX Deployment.
        :param str name: Specify the name of the autoscaling profile.
        """
        pulumi.set(__self__, "max_capacity", max_capacity)
        pulumi.set(__self__, "min_capacity", min_capacity)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="maxCapacity")
    def max_capacity(self) -> int:
        return pulumi.get(self, "max_capacity")

    @property
    @pulumi.getter(name="minCapacity")
    def min_capacity(self) -> int:
        """
        Specify the minimum number of NGINX capacity units for this NGINX Deployment.
        """
        return pulumi.get(self, "min_capacity")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Specify the name of the autoscaling profile.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class DeploymentFrontendPrivate(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allocationMethod":
            suggest = "allocation_method"
        elif key == "ipAddress":
            suggest = "ip_address"
        elif key == "subnetId":
            suggest = "subnet_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentFrontendPrivate. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentFrontendPrivate.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentFrontendPrivate.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allocation_method: str,
                 ip_address: str,
                 subnet_id: str):
        """
        :param str allocation_method: Specify the method for allocating the private IP. Possible values are `Static` and `Dynamic`. Changing this forces a new NGINX Deployment to be created.
        :param str ip_address: Specify the private IP Address. Changing this forces a new NGINX Deployment to be created.
        :param str subnet_id: Specify the Subnet Resource ID for this NGINX Deployment. Changing this forces a new NGINX Deployment to be created.
        """
        pulumi.set(__self__, "allocation_method", allocation_method)
        pulumi.set(__self__, "ip_address", ip_address)
        pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="allocationMethod")
    def allocation_method(self) -> str:
        """
        Specify the method for allocating the private IP. Possible values are `Static` and `Dynamic`. Changing this forces a new NGINX Deployment to be created.
        """
        return pulumi.get(self, "allocation_method")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> str:
        """
        Specify the private IP Address. Changing this forces a new NGINX Deployment to be created.
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        """
        Specify the Subnet Resource ID for this NGINX Deployment. Changing this forces a new NGINX Deployment to be created.
        """
        return pulumi.get(self, "subnet_id")


@pulumi.output_type
class DeploymentFrontendPublic(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ipAddresses":
            suggest = "ip_addresses"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentFrontendPublic. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentFrontendPublic.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentFrontendPublic.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ip_addresses: Optional[Sequence[str]] = None):
        """
        :param Sequence[str] ip_addresses: Specifies a list of Public IP Resource ID to this NGINX Deployment. Changing this forces a new NGINX Deployment to be created.
        """
        if ip_addresses is not None:
            pulumi.set(__self__, "ip_addresses", ip_addresses)

    @property
    @pulumi.getter(name="ipAddresses")
    def ip_addresses(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of Public IP Resource ID to this NGINX Deployment. Changing this forces a new NGINX Deployment to be created.
        """
        return pulumi.get(self, "ip_addresses")


@pulumi.output_type
class DeploymentIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the identity type of the NGINX Deployment. Possible values are `SystemAssigned`, `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param Sequence[str] identity_ids: Specifies a list of user managed identity ids to be assigned.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned`.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the identity type of the NGINX Deployment. Possible values are `SystemAssigned`, `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of user managed identity ids to be assigned.

        > **NOTE:** This is required when `type` is set to `UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class DeploymentLoggingStorageAccount(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "containerName":
            suggest = "container_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentLoggingStorageAccount. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentLoggingStorageAccount.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentLoggingStorageAccount.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 container_name: Optional[str] = None,
                 name: Optional[str] = None):
        """
        :param str name: The name which should be used for this NGINX Deployment. Changing this forces a new NGINX Deployment to be created.
        """
        if container_name is not None:
            pulumi.set(__self__, "container_name", container_name)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="containerName")
    def container_name(self) -> Optional[str]:
        return pulumi.get(self, "container_name")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name which should be used for this NGINX Deployment. Changing this forces a new NGINX Deployment to be created.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class DeploymentNetworkInterface(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "subnetId":
            suggest = "subnet_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentNetworkInterface. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentNetworkInterface.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentNetworkInterface.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 subnet_id: str):
        """
        :param str subnet_id: Specify The Subnet Resource ID for this NGINX Deployment. Changing this forces a new NGINX Deployment to be created.
        """
        pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        """
        Specify The Subnet Resource ID for this NGINX Deployment. Changing this forces a new NGINX Deployment to be created.
        """
        return pulumi.get(self, "subnet_id")


@pulumi.output_type
class GetConfigurationConfigFileResult(dict):
    def __init__(__self__, *,
                 content: str,
                 virtual_path: str):
        """
        :param str content: The base-64 encoded contents of this configuration file.
        :param str virtual_path: The path of this configuration file.
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "virtual_path", virtual_path)

    @property
    @pulumi.getter
    def content(self) -> str:
        """
        The base-64 encoded contents of this configuration file.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="virtualPath")
    def virtual_path(self) -> str:
        """
        The path of this configuration file.
        """
        return pulumi.get(self, "virtual_path")


@pulumi.output_type
class GetConfigurationProtectedFileResult(dict):
    def __init__(__self__, *,
                 content: str,
                 virtual_path: str):
        """
        :param str content: The base-64 encoded contents of this configuration file.
        :param str virtual_path: The path of this configuration file.
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "virtual_path", virtual_path)

    @property
    @pulumi.getter
    @_utilities.deprecated("""the `content` property is deprecated and will be removed in v5.0 of the AzureRM Provider.""")
    def content(self) -> str:
        """
        The base-64 encoded contents of this configuration file.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="virtualPath")
    def virtual_path(self) -> str:
        """
        The path of this configuration file.
        """
        return pulumi.get(self, "virtual_path")


@pulumi.output_type
class GetDeploymentAutoScaleProfileResult(dict):
    def __init__(__self__, *,
                 max_capacity: int,
                 min_capacity: int,
                 name: str):
        """
        :param int max_capacity: The maximum number of NGINX capacity units for this NGINX Deployment.
        :param int min_capacity: The minimum number of NGINX capacity units for this NGINX Deployment.
        :param str name: The name of this NGINX Deployment.
        """
        pulumi.set(__self__, "max_capacity", max_capacity)
        pulumi.set(__self__, "min_capacity", min_capacity)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="maxCapacity")
    def max_capacity(self) -> int:
        """
        The maximum number of NGINX capacity units for this NGINX Deployment.
        """
        return pulumi.get(self, "max_capacity")

    @property
    @pulumi.getter(name="minCapacity")
    def min_capacity(self) -> int:
        """
        The minimum number of NGINX capacity units for this NGINX Deployment.
        """
        return pulumi.get(self, "min_capacity")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of this NGINX Deployment.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetDeploymentFrontendPrivateResult(dict):
    def __init__(__self__, *,
                 allocation_method: str,
                 ip_address: str,
                 subnet_id: str):
        """
        :param str allocation_method: The method of allocating the private IP to the NGINX Deployment.
        :param str ip_address: The list of Public IP Resource IDs for this NGINX Deployment.
        :param str subnet_id: The subnet resource ID of the NGINX Deployment.
        """
        pulumi.set(__self__, "allocation_method", allocation_method)
        pulumi.set(__self__, "ip_address", ip_address)
        pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="allocationMethod")
    def allocation_method(self) -> str:
        """
        The method of allocating the private IP to the NGINX Deployment.
        """
        return pulumi.get(self, "allocation_method")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> str:
        """
        The list of Public IP Resource IDs for this NGINX Deployment.
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        """
        The subnet resource ID of the NGINX Deployment.
        """
        return pulumi.get(self, "subnet_id")


@pulumi.output_type
class GetDeploymentFrontendPublicResult(dict):
    def __init__(__self__, *,
                 ip_addresses: Sequence[str]):
        """
        :param Sequence[str] ip_addresses: The list of Public IP Resource IDs for this NGINX Deployment.
        """
        pulumi.set(__self__, "ip_addresses", ip_addresses)

    @property
    @pulumi.getter(name="ipAddresses")
    def ip_addresses(self) -> Sequence[str]:
        """
        The list of Public IP Resource IDs for this NGINX Deployment.
        """
        return pulumi.get(self, "ip_addresses")


@pulumi.output_type
class GetDeploymentIdentityResult(dict):
    def __init__(__self__, *,
                 identity_ids: Sequence[str],
                 principal_id: str,
                 tenant_id: str,
                 type: str):
        """
        :param Sequence[str] identity_ids: List of identities attached to the NGINX Deployment.
        :param str type: Type of identity attached to the NGINX Deployment.
        """
        pulumi.set(__self__, "identity_ids", identity_ids)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "tenant_id", tenant_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Sequence[str]:
        """
        List of identities attached to the NGINX Deployment.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> str:
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Type of identity attached to the NGINX Deployment.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetDeploymentLoggingStorageAccountResult(dict):
    def __init__(__self__, *,
                 container_name: str,
                 name: str):
        """
        :param str name: The name of this NGINX Deployment.
        """
        pulumi.set(__self__, "container_name", container_name)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="containerName")
    def container_name(self) -> str:
        return pulumi.get(self, "container_name")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of this NGINX Deployment.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetDeploymentNetworkInterfaceResult(dict):
    def __init__(__self__, *,
                 subnet_id: str):
        """
        :param str subnet_id: The subnet resource ID of the NGINX Deployment.
        """
        pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        """
        The subnet resource ID of the NGINX Deployment.
        """
        return pulumi.get(self, "subnet_id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DataSourceWindowsEventArgs', 'DataSourceWindowsEvent']

@pulumi.input_type
class DataSourceWindowsEventArgs:
    def __init__(__self__, *,
                 event_log_name: pulumi.Input[str],
                 event_types: pulumi.Input[Sequence[pulumi.Input[str]]],
                 resource_group_name: pulumi.Input[str],
                 workspace_name: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DataSourceWindowsEvent resource.
        :param pulumi.Input[str] event_log_name: Specifies the name of the Windows Event Log to collect events from.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_types: Specifies an array of event types applied to the specified event log. Possible values include `Error`, `Warning` and `Information`.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        :param pulumi.Input[str] workspace_name: The name of the Log Analytics Workspace where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        :param pulumi.Input[str] name: The name which should be used for this Log Analytics Windows Event DataSource. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        pulumi.set(__self__, "event_log_name", event_log_name)
        pulumi.set(__self__, "event_types", event_types)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "workspace_name", workspace_name)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="eventLogName")
    def event_log_name(self) -> pulumi.Input[str]:
        """
        Specifies the name of the Windows Event Log to collect events from.
        """
        return pulumi.get(self, "event_log_name")

    @event_log_name.setter
    def event_log_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "event_log_name", value)

    @property
    @pulumi.getter(name="eventTypes")
    def event_types(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Specifies an array of event types applied to the specified event log. Possible values include `Error`, `Warning` and `Information`.
        """
        return pulumi.get(self, "event_types")

    @event_types.setter
    def event_types(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "event_types", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the Resource Group where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="workspaceName")
    def workspace_name(self) -> pulumi.Input[str]:
        """
        The name of the Log Analytics Workspace where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        return pulumi.get(self, "workspace_name")

    @workspace_name.setter
    def workspace_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "workspace_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Log Analytics Windows Event DataSource. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _DataSourceWindowsEventState:
    def __init__(__self__, *,
                 event_log_name: Optional[pulumi.Input[str]] = None,
                 event_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 workspace_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DataSourceWindowsEvent resources.
        :param pulumi.Input[str] event_log_name: Specifies the name of the Windows Event Log to collect events from.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_types: Specifies an array of event types applied to the specified event log. Possible values include `Error`, `Warning` and `Information`.
        :param pulumi.Input[str] name: The name which should be used for this Log Analytics Windows Event DataSource. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        :param pulumi.Input[str] workspace_name: The name of the Log Analytics Workspace where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        if event_log_name is not None:
            pulumi.set(__self__, "event_log_name", event_log_name)
        if event_types is not None:
            pulumi.set(__self__, "event_types", event_types)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if workspace_name is not None:
            pulumi.set(__self__, "workspace_name", workspace_name)

    @property
    @pulumi.getter(name="eventLogName")
    def event_log_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Windows Event Log to collect events from.
        """
        return pulumi.get(self, "event_log_name")

    @event_log_name.setter
    def event_log_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_log_name", value)

    @property
    @pulumi.getter(name="eventTypes")
    def event_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies an array of event types applied to the specified event log. Possible values include `Error`, `Warning` and `Information`.
        """
        return pulumi.get(self, "event_types")

    @event_types.setter
    def event_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "event_types", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Log Analytics Windows Event DataSource. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Resource Group where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="workspaceName")
    def workspace_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Log Analytics Workspace where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        return pulumi.get(self, "workspace_name")

    @workspace_name.setter
    def workspace_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "workspace_name", value)


class DataSourceWindowsEvent(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 event_log_name: Optional[pulumi.Input[str]] = None,
                 event_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 workspace_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Log Analytics Windows Event DataSource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_analytics_workspace = azure.operationalinsights.AnalyticsWorkspace("example",
            name="example-law",
            location=example.location,
            resource_group_name=example.name,
            sku="PerGB2018")
        example_data_source_windows_event = azure.loganalytics.DataSourceWindowsEvent("example",
            name="example-lad-wpc",
            resource_group_name=example.name,
            workspace_name=example_analytics_workspace.name,
            event_log_name="Application",
            event_types=["Error"])
        ```

        ## Import

        Log Analytics Windows Event DataSources can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:loganalytics/dataSourceWindowsEvent:DataSourceWindowsEvent example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.OperationalInsights/workspaces/workspace1/dataSources/datasource1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] event_log_name: Specifies the name of the Windows Event Log to collect events from.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_types: Specifies an array of event types applied to the specified event log. Possible values include `Error`, `Warning` and `Information`.
        :param pulumi.Input[str] name: The name which should be used for this Log Analytics Windows Event DataSource. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        :param pulumi.Input[str] workspace_name: The name of the Log Analytics Workspace where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataSourceWindowsEventArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Log Analytics Windows Event DataSource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_analytics_workspace = azure.operationalinsights.AnalyticsWorkspace("example",
            name="example-law",
            location=example.location,
            resource_group_name=example.name,
            sku="PerGB2018")
        example_data_source_windows_event = azure.loganalytics.DataSourceWindowsEvent("example",
            name="example-lad-wpc",
            resource_group_name=example.name,
            workspace_name=example_analytics_workspace.name,
            event_log_name="Application",
            event_types=["Error"])
        ```

        ## Import

        Log Analytics Windows Event DataSources can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:loganalytics/dataSourceWindowsEvent:DataSourceWindowsEvent example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.OperationalInsights/workspaces/workspace1/dataSources/datasource1
        ```

        :param str resource_name: The name of the resource.
        :param DataSourceWindowsEventArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataSourceWindowsEventArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 event_log_name: Optional[pulumi.Input[str]] = None,
                 event_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 workspace_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataSourceWindowsEventArgs.__new__(DataSourceWindowsEventArgs)

            if event_log_name is None and not opts.urn:
                raise TypeError("Missing required property 'event_log_name'")
            __props__.__dict__["event_log_name"] = event_log_name
            if event_types is None and not opts.urn:
                raise TypeError("Missing required property 'event_types'")
            __props__.__dict__["event_types"] = event_types
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if workspace_name is None and not opts.urn:
                raise TypeError("Missing required property 'workspace_name'")
            __props__.__dict__["workspace_name"] = workspace_name
        super(DataSourceWindowsEvent, __self__).__init__(
            'azure:loganalytics/dataSourceWindowsEvent:DataSourceWindowsEvent',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            event_log_name: Optional[pulumi.Input[str]] = None,
            event_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            workspace_name: Optional[pulumi.Input[str]] = None) -> 'DataSourceWindowsEvent':
        """
        Get an existing DataSourceWindowsEvent resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] event_log_name: Specifies the name of the Windows Event Log to collect events from.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_types: Specifies an array of event types applied to the specified event log. Possible values include `Error`, `Warning` and `Information`.
        :param pulumi.Input[str] name: The name which should be used for this Log Analytics Windows Event DataSource. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        :param pulumi.Input[str] workspace_name: The name of the Log Analytics Workspace where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataSourceWindowsEventState.__new__(_DataSourceWindowsEventState)

        __props__.__dict__["event_log_name"] = event_log_name
        __props__.__dict__["event_types"] = event_types
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["workspace_name"] = workspace_name
        return DataSourceWindowsEvent(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="eventLogName")
    def event_log_name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the Windows Event Log to collect events from.
        """
        return pulumi.get(self, "event_log_name")

    @property
    @pulumi.getter(name="eventTypes")
    def event_types(self) -> pulumi.Output[Sequence[str]]:
        """
        Specifies an array of event types applied to the specified event log. Possible values include `Error`, `Warning` and `Information`.
        """
        return pulumi.get(self, "event_types")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this Log Analytics Windows Event DataSource. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the Resource Group where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="workspaceName")
    def workspace_name(self) -> pulumi.Output[str]:
        """
        The name of the Log Analytics Workspace where the Log Analytics Windows Event DataSource should exist. Changing this forces a new Log Analytics Windows Event DataSource to be created.
        """
        return pulumi.get(self, "workspace_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RegistryCredentialSetArgs', 'RegistryCredentialSet']

@pulumi.input_type
class RegistryCredentialSetArgs:
    def __init__(__self__, *,
                 authentication_credentials: pulumi.Input['RegistryCredentialSetAuthenticationCredentialsArgs'],
                 container_registry_id: pulumi.Input[str],
                 identity: pulumi.Input['RegistryCredentialSetIdentityArgs'],
                 login_server: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a RegistryCredentialSet resource.
        :param pulumi.Input['RegistryCredentialSetAuthenticationCredentialsArgs'] authentication_credentials: A `authentication_credentials` block as defined below.
        :param pulumi.Input[str] container_registry_id: The ID of the Container Registry. Changing this forces a new Container Registry Credential Set to be created.
        :param pulumi.Input['RegistryCredentialSetIdentityArgs'] identity: An `identity` block as defined below.
        :param pulumi.Input[str] login_server: The login server for the Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        :param pulumi.Input[str] name: The name which should be used for this Container Registry Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        pulumi.set(__self__, "authentication_credentials", authentication_credentials)
        pulumi.set(__self__, "container_registry_id", container_registry_id)
        pulumi.set(__self__, "identity", identity)
        pulumi.set(__self__, "login_server", login_server)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="authenticationCredentials")
    def authentication_credentials(self) -> pulumi.Input['RegistryCredentialSetAuthenticationCredentialsArgs']:
        """
        A `authentication_credentials` block as defined below.
        """
        return pulumi.get(self, "authentication_credentials")

    @authentication_credentials.setter
    def authentication_credentials(self, value: pulumi.Input['RegistryCredentialSetAuthenticationCredentialsArgs']):
        pulumi.set(self, "authentication_credentials", value)

    @property
    @pulumi.getter(name="containerRegistryId")
    def container_registry_id(self) -> pulumi.Input[str]:
        """
        The ID of the Container Registry. Changing this forces a new Container Registry Credential Set to be created.
        """
        return pulumi.get(self, "container_registry_id")

    @container_registry_id.setter
    def container_registry_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "container_registry_id", value)

    @property
    @pulumi.getter
    def identity(self) -> pulumi.Input['RegistryCredentialSetIdentityArgs']:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: pulumi.Input['RegistryCredentialSetIdentityArgs']):
        pulumi.set(self, "identity", value)

    @property
    @pulumi.getter(name="loginServer")
    def login_server(self) -> pulumi.Input[str]:
        """
        The login server for the Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        return pulumi.get(self, "login_server")

    @login_server.setter
    def login_server(self, value: pulumi.Input[str]):
        pulumi.set(self, "login_server", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Container Registry Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _RegistryCredentialSetState:
    def __init__(__self__, *,
                 authentication_credentials: Optional[pulumi.Input['RegistryCredentialSetAuthenticationCredentialsArgs']] = None,
                 container_registry_id: Optional[pulumi.Input[str]] = None,
                 identity: Optional[pulumi.Input['RegistryCredentialSetIdentityArgs']] = None,
                 login_server: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RegistryCredentialSet resources.
        :param pulumi.Input['RegistryCredentialSetAuthenticationCredentialsArgs'] authentication_credentials: A `authentication_credentials` block as defined below.
        :param pulumi.Input[str] container_registry_id: The ID of the Container Registry. Changing this forces a new Container Registry Credential Set to be created.
        :param pulumi.Input['RegistryCredentialSetIdentityArgs'] identity: An `identity` block as defined below.
        :param pulumi.Input[str] login_server: The login server for the Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        :param pulumi.Input[str] name: The name which should be used for this Container Registry Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        if authentication_credentials is not None:
            pulumi.set(__self__, "authentication_credentials", authentication_credentials)
        if container_registry_id is not None:
            pulumi.set(__self__, "container_registry_id", container_registry_id)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if login_server is not None:
            pulumi.set(__self__, "login_server", login_server)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="authenticationCredentials")
    def authentication_credentials(self) -> Optional[pulumi.Input['RegistryCredentialSetAuthenticationCredentialsArgs']]:
        """
        A `authentication_credentials` block as defined below.
        """
        return pulumi.get(self, "authentication_credentials")

    @authentication_credentials.setter
    def authentication_credentials(self, value: Optional[pulumi.Input['RegistryCredentialSetAuthenticationCredentialsArgs']]):
        pulumi.set(self, "authentication_credentials", value)

    @property
    @pulumi.getter(name="containerRegistryId")
    def container_registry_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Container Registry. Changing this forces a new Container Registry Credential Set to be created.
        """
        return pulumi.get(self, "container_registry_id")

    @container_registry_id.setter
    def container_registry_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_registry_id", value)

    @property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input['RegistryCredentialSetIdentityArgs']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input['RegistryCredentialSetIdentityArgs']]):
        pulumi.set(self, "identity", value)

    @property
    @pulumi.getter(name="loginServer")
    def login_server(self) -> Optional[pulumi.Input[str]]:
        """
        The login server for the Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        return pulumi.get(self, "login_server")

    @login_server.setter
    def login_server(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "login_server", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Container Registry Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class RegistryCredentialSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_credentials: Optional[pulumi.Input[Union['RegistryCredentialSetAuthenticationCredentialsArgs', 'RegistryCredentialSetAuthenticationCredentialsArgsDict']]] = None,
                 container_registry_id: Optional[pulumi.Input[str]] = None,
                 identity: Optional[pulumi.Input[Union['RegistryCredentialSetIdentityArgs', 'RegistryCredentialSetIdentityArgsDict']]] = None,
                 login_server: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Container Registry Credential Set.

        ## Example Usage

        ### Minimal)

        > NOTE: Be aware that you will need to permit the Identity that is created for the Container Registry to have `get` on secrets to the Key Vault, e.g. using the `keyvault.AccessPolicy` resource.

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_registry = azure.containerservice.Registry("example",
            name="exampleContainerRegistry",
            resource_group_name=example.name,
            location=example.location,
            sku="Basic")
        example_registry_credential_set = azure.containerservice.RegistryCredentialSet("example",
            name="exampleCredentialSet",
            container_registry_id="azurerm_container_registry.example.id",
            login_server="docker.io",
            identity={
                "type": "SystemAssigned",
            },
            authentication_credentials={
                "username_secret_id": "https://example-keyvault.vault.azure.net/secrets/example-user-name",
                "password_secret_id": "https://example-keyvault.vault.azure.net/secrets/example-user-password",
            })
        ```

        ### Full)

        This example provisions a key vault with two secrets, a container registry, a container registry credential set, and an access policy to allow the container registry to read the secrets from the key vault.

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        current = azure.core.get_client_config()
        example_key_vault = azure.keyvault.KeyVault("example",
            name="examplekeyvault",
            location=example.location,
            resource_group_name=example.name,
            tenant_id=current.tenant_id,
            sku_name="standard",
            soft_delete_retention_days=7,
            access_policies=[{
                "tenant_id": current.tenant_id,
                "object_id": current.object_id,
                "certificate_permissions": [],
                "key_permissions": [],
                "secret_permissions": [
                    "Get",
                    "Set",
                    "Delete",
                    "Purge",
                ],
            }])
        example_user = azure.keyvault.Secret("example_user",
            key_vault_id=example_key_vault.id,
            name="example-user-name",
            value="name")
        example_password = azure.keyvault.Secret("example_password",
            key_vault_id=example_key_vault.id,
            name="example-user-password",
            value="password")
        example_registry = azure.containerservice.Registry("example",
            name="exampleContainerRegistry",
            resource_group_name=example.name,
            location=example.location,
            sku="Basic")
        example_registry_credential_set = azure.containerservice.RegistryCredentialSet("example",
            name="exampleCredentialSet",
            container_registry_id="azurerm_container_registry.example.id",
            login_server="docker.io",
            identity={
                "type": "SystemAssigned",
            },
            authentication_credentials={
                "username_secret_id": example_user.versionless_id,
                "password_secret_id": example_password.versionless_id,
            })
        read_secrets = azure.keyvault.AccessPolicy("read_secrets",
            key_vault_id=example_key_vault.id,
            tenant_id=example_registry_credential_set.identity.tenant_id,
            object_id=example_registry_credential_set.identity.principal_id,
            secret_permissions=["Get"])
        ```

        ## Import

        Container Registry Credential Sets can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:containerservice/registryCredentialSet:RegistryCredentialSet example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ContainerRegistry/registries/registry1/credentialSets/credentialSet1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RegistryCredentialSetAuthenticationCredentialsArgs', 'RegistryCredentialSetAuthenticationCredentialsArgsDict']] authentication_credentials: A `authentication_credentials` block as defined below.
        :param pulumi.Input[str] container_registry_id: The ID of the Container Registry. Changing this forces a new Container Registry Credential Set to be created.
        :param pulumi.Input[Union['RegistryCredentialSetIdentityArgs', 'RegistryCredentialSetIdentityArgsDict']] identity: An `identity` block as defined below.
        :param pulumi.Input[str] login_server: The login server for the Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        :param pulumi.Input[str] name: The name which should be used for this Container Registry Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RegistryCredentialSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Container Registry Credential Set.

        ## Example Usage

        ### Minimal)

        > NOTE: Be aware that you will need to permit the Identity that is created for the Container Registry to have `get` on secrets to the Key Vault, e.g. using the `keyvault.AccessPolicy` resource.

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_registry = azure.containerservice.Registry("example",
            name="exampleContainerRegistry",
            resource_group_name=example.name,
            location=example.location,
            sku="Basic")
        example_registry_credential_set = azure.containerservice.RegistryCredentialSet("example",
            name="exampleCredentialSet",
            container_registry_id="azurerm_container_registry.example.id",
            login_server="docker.io",
            identity={
                "type": "SystemAssigned",
            },
            authentication_credentials={
                "username_secret_id": "https://example-keyvault.vault.azure.net/secrets/example-user-name",
                "password_secret_id": "https://example-keyvault.vault.azure.net/secrets/example-user-password",
            })
        ```

        ### Full)

        This example provisions a key vault with two secrets, a container registry, a container registry credential set, and an access policy to allow the container registry to read the secrets from the key vault.

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        current = azure.core.get_client_config()
        example_key_vault = azure.keyvault.KeyVault("example",
            name="examplekeyvault",
            location=example.location,
            resource_group_name=example.name,
            tenant_id=current.tenant_id,
            sku_name="standard",
            soft_delete_retention_days=7,
            access_policies=[{
                "tenant_id": current.tenant_id,
                "object_id": current.object_id,
                "certificate_permissions": [],
                "key_permissions": [],
                "secret_permissions": [
                    "Get",
                    "Set",
                    "Delete",
                    "Purge",
                ],
            }])
        example_user = azure.keyvault.Secret("example_user",
            key_vault_id=example_key_vault.id,
            name="example-user-name",
            value="name")
        example_password = azure.keyvault.Secret("example_password",
            key_vault_id=example_key_vault.id,
            name="example-user-password",
            value="password")
        example_registry = azure.containerservice.Registry("example",
            name="exampleContainerRegistry",
            resource_group_name=example.name,
            location=example.location,
            sku="Basic")
        example_registry_credential_set = azure.containerservice.RegistryCredentialSet("example",
            name="exampleCredentialSet",
            container_registry_id="azurerm_container_registry.example.id",
            login_server="docker.io",
            identity={
                "type": "SystemAssigned",
            },
            authentication_credentials={
                "username_secret_id": example_user.versionless_id,
                "password_secret_id": example_password.versionless_id,
            })
        read_secrets = azure.keyvault.AccessPolicy("read_secrets",
            key_vault_id=example_key_vault.id,
            tenant_id=example_registry_credential_set.identity.tenant_id,
            object_id=example_registry_credential_set.identity.principal_id,
            secret_permissions=["Get"])
        ```

        ## Import

        Container Registry Credential Sets can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:containerservice/registryCredentialSet:RegistryCredentialSet example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ContainerRegistry/registries/registry1/credentialSets/credentialSet1
        ```

        :param str resource_name: The name of the resource.
        :param RegistryCredentialSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RegistryCredentialSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_credentials: Optional[pulumi.Input[Union['RegistryCredentialSetAuthenticationCredentialsArgs', 'RegistryCredentialSetAuthenticationCredentialsArgsDict']]] = None,
                 container_registry_id: Optional[pulumi.Input[str]] = None,
                 identity: Optional[pulumi.Input[Union['RegistryCredentialSetIdentityArgs', 'RegistryCredentialSetIdentityArgsDict']]] = None,
                 login_server: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RegistryCredentialSetArgs.__new__(RegistryCredentialSetArgs)

            if authentication_credentials is None and not opts.urn:
                raise TypeError("Missing required property 'authentication_credentials'")
            __props__.__dict__["authentication_credentials"] = authentication_credentials
            if container_registry_id is None and not opts.urn:
                raise TypeError("Missing required property 'container_registry_id'")
            __props__.__dict__["container_registry_id"] = container_registry_id
            if identity is None and not opts.urn:
                raise TypeError("Missing required property 'identity'")
            __props__.__dict__["identity"] = identity
            if login_server is None and not opts.urn:
                raise TypeError("Missing required property 'login_server'")
            __props__.__dict__["login_server"] = login_server
            __props__.__dict__["name"] = name
        super(RegistryCredentialSet, __self__).__init__(
            'azure:containerservice/registryCredentialSet:RegistryCredentialSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authentication_credentials: Optional[pulumi.Input[Union['RegistryCredentialSetAuthenticationCredentialsArgs', 'RegistryCredentialSetAuthenticationCredentialsArgsDict']]] = None,
            container_registry_id: Optional[pulumi.Input[str]] = None,
            identity: Optional[pulumi.Input[Union['RegistryCredentialSetIdentityArgs', 'RegistryCredentialSetIdentityArgsDict']]] = None,
            login_server: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'RegistryCredentialSet':
        """
        Get an existing RegistryCredentialSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RegistryCredentialSetAuthenticationCredentialsArgs', 'RegistryCredentialSetAuthenticationCredentialsArgsDict']] authentication_credentials: A `authentication_credentials` block as defined below.
        :param pulumi.Input[str] container_registry_id: The ID of the Container Registry. Changing this forces a new Container Registry Credential Set to be created.
        :param pulumi.Input[Union['RegistryCredentialSetIdentityArgs', 'RegistryCredentialSetIdentityArgsDict']] identity: An `identity` block as defined below.
        :param pulumi.Input[str] login_server: The login server for the Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        :param pulumi.Input[str] name: The name which should be used for this Container Registry Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RegistryCredentialSetState.__new__(_RegistryCredentialSetState)

        __props__.__dict__["authentication_credentials"] = authentication_credentials
        __props__.__dict__["container_registry_id"] = container_registry_id
        __props__.__dict__["identity"] = identity
        __props__.__dict__["login_server"] = login_server
        __props__.__dict__["name"] = name
        return RegistryCredentialSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authenticationCredentials")
    def authentication_credentials(self) -> pulumi.Output['outputs.RegistryCredentialSetAuthenticationCredentials']:
        """
        A `authentication_credentials` block as defined below.
        """
        return pulumi.get(self, "authentication_credentials")

    @property
    @pulumi.getter(name="containerRegistryId")
    def container_registry_id(self) -> pulumi.Output[str]:
        """
        The ID of the Container Registry. Changing this forces a new Container Registry Credential Set to be created.
        """
        return pulumi.get(self, "container_registry_id")

    @property
    @pulumi.getter
    def identity(self) -> pulumi.Output['outputs.RegistryCredentialSetIdentity']:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @property
    @pulumi.getter(name="loginServer")
    def login_server(self) -> pulumi.Output[str]:
        """
        The login server for the Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        return pulumi.get(self, "login_server")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this Container Registry Credential Set. Changing this forces a new Container Registry Credential Set to be created.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ServiceInitialReplicaSetArgs',
    'ServiceInitialReplicaSetArgsDict',
    'ServiceNotificationsArgs',
    'ServiceNotificationsArgsDict',
    'ServiceSecureLdapArgs',
    'ServiceSecureLdapArgsDict',
    'ServiceSecurityArgs',
    'ServiceSecurityArgsDict',
]

MYPY = False

if not MYPY:
    class ServiceInitialReplicaSetArgsDict(TypedDict):
        subnet_id: pulumi.Input[str]
        """
        The ID of the subnet in which to place the initial replica set. Changing this forces a new resource to be created.
        """
        domain_controller_ip_addresses: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        A list of subnet IP addresses for the domain controllers in the initial replica set, typically two.
        """
        external_access_ip_address: NotRequired[pulumi.Input[str]]
        """
        The publicly routable IP address for the domain controllers in the initial replica set.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        A unique ID for the replica set.
        """
        location: NotRequired[pulumi.Input[str]]
        """
        The Azure location where the Domain Service exists. Changing this forces a new resource to be created.
        """
        service_status: NotRequired[pulumi.Input[str]]
        """
        The current service status for the initial replica set.
        """
elif False:
    ServiceInitialReplicaSetArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceInitialReplicaSetArgs:
    def __init__(__self__, *,
                 subnet_id: pulumi.Input[str],
                 domain_controller_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 external_access_ip_address: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 service_status: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] subnet_id: The ID of the subnet in which to place the initial replica set. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] domain_controller_ip_addresses: A list of subnet IP addresses for the domain controllers in the initial replica set, typically two.
        :param pulumi.Input[str] external_access_ip_address: The publicly routable IP address for the domain controllers in the initial replica set.
        :param pulumi.Input[str] id: A unique ID for the replica set.
        :param pulumi.Input[str] location: The Azure location where the Domain Service exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] service_status: The current service status for the initial replica set.
        """
        pulumi.set(__self__, "subnet_id", subnet_id)
        if domain_controller_ip_addresses is not None:
            pulumi.set(__self__, "domain_controller_ip_addresses", domain_controller_ip_addresses)
        if external_access_ip_address is not None:
            pulumi.set(__self__, "external_access_ip_address", external_access_ip_address)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if service_status is not None:
            pulumi.set(__self__, "service_status", service_status)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[str]:
        """
        The ID of the subnet in which to place the initial replica set. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="domainControllerIpAddresses")
    def domain_controller_ip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of subnet IP addresses for the domain controllers in the initial replica set, typically two.
        """
        return pulumi.get(self, "domain_controller_ip_addresses")

    @domain_controller_ip_addresses.setter
    def domain_controller_ip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "domain_controller_ip_addresses", value)

    @property
    @pulumi.getter(name="externalAccessIpAddress")
    def external_access_ip_address(self) -> Optional[pulumi.Input[str]]:
        """
        The publicly routable IP address for the domain controllers in the initial replica set.
        """
        return pulumi.get(self, "external_access_ip_address")

    @external_access_ip_address.setter
    def external_access_ip_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_access_ip_address", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        A unique ID for the replica set.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The Azure location where the Domain Service exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="serviceStatus")
    def service_status(self) -> Optional[pulumi.Input[str]]:
        """
        The current service status for the initial replica set.
        """
        return pulumi.get(self, "service_status")

    @service_status.setter
    def service_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_status", value)


if not MYPY:
    class ServiceNotificationsArgsDict(TypedDict):
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        A list of additional email addresses to notify when there are alerts in the managed domain.
        """
        notify_dc_admins: NotRequired[pulumi.Input[bool]]
        """
        Whether to notify members of the _AAD DC Administrators_ group when there are alerts in the managed domain.
        """
        notify_global_admins: NotRequired[pulumi.Input[bool]]
        """
        Whether to notify all Global Administrators when there are alerts in the managed domain.
        """
elif False:
    ServiceNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceNotificationsArgs:
    def __init__(__self__, *,
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 notify_dc_admins: Optional[pulumi.Input[bool]] = None,
                 notify_global_admins: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: A list of additional email addresses to notify when there are alerts in the managed domain.
        :param pulumi.Input[bool] notify_dc_admins: Whether to notify members of the _AAD DC Administrators_ group when there are alerts in the managed domain.
        :param pulumi.Input[bool] notify_global_admins: Whether to notify all Global Administrators when there are alerts in the managed domain.
        """
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)
        if notify_dc_admins is not None:
            pulumi.set(__self__, "notify_dc_admins", notify_dc_admins)
        if notify_global_admins is not None:
            pulumi.set(__self__, "notify_global_admins", notify_global_admins)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of additional email addresses to notify when there are alerts in the managed domain.
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)

    @property
    @pulumi.getter(name="notifyDcAdmins")
    def notify_dc_admins(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to notify members of the _AAD DC Administrators_ group when there are alerts in the managed domain.
        """
        return pulumi.get(self, "notify_dc_admins")

    @notify_dc_admins.setter
    def notify_dc_admins(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "notify_dc_admins", value)

    @property
    @pulumi.getter(name="notifyGlobalAdmins")
    def notify_global_admins(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to notify all Global Administrators when there are alerts in the managed domain.
        """
        return pulumi.get(self, "notify_global_admins")

    @notify_global_admins.setter
    def notify_global_admins(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "notify_global_admins", value)


if not MYPY:
    class ServiceSecureLdapArgsDict(TypedDict):
        enabled: pulumi.Input[bool]
        """
        Whether to enable secure LDAP for the managed domain. For more information, please see [official documentation on enabling LDAPS](https://docs.microsoft.com/azure/active-directory-domain-services/tutorial-configure-ldaps), paying particular attention to the section on network security to avoid unnecessarily exposing your service to Internet-borne bruteforce attacks.
        """
        pfx_certificate: pulumi.Input[str]
        """
        The certificate/private key to use for LDAPS, as a base64-encoded TripleDES-SHA1 encrypted PKCS#12 bundle (PFX file).
        """
        pfx_certificate_password: pulumi.Input[str]
        """
        The password to use for decrypting the PKCS#12 bundle (PFX file).
        """
        certificate_expiry: NotRequired[pulumi.Input[str]]
        """
        The expiry time of the certificate.
        """
        certificate_thumbprint: NotRequired[pulumi.Input[str]]
        """
        The thumbprint of the certificate.
        """
        external_access_enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether to enable external access to LDAPS over the Internet. Defaults to `false`.
        """
        public_certificate: NotRequired[pulumi.Input[str]]
        """
        The public certificate.
        """
elif False:
    ServiceSecureLdapArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceSecureLdapArgs:
    def __init__(__self__, *,
                 enabled: pulumi.Input[bool],
                 pfx_certificate: pulumi.Input[str],
                 pfx_certificate_password: pulumi.Input[str],
                 certificate_expiry: Optional[pulumi.Input[str]] = None,
                 certificate_thumbprint: Optional[pulumi.Input[str]] = None,
                 external_access_enabled: Optional[pulumi.Input[bool]] = None,
                 public_certificate: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] enabled: Whether to enable secure LDAP for the managed domain. For more information, please see [official documentation on enabling LDAPS](https://docs.microsoft.com/azure/active-directory-domain-services/tutorial-configure-ldaps), paying particular attention to the section on network security to avoid unnecessarily exposing your service to Internet-borne bruteforce attacks.
        :param pulumi.Input[str] pfx_certificate: The certificate/private key to use for LDAPS, as a base64-encoded TripleDES-SHA1 encrypted PKCS#12 bundle (PFX file).
        :param pulumi.Input[str] pfx_certificate_password: The password to use for decrypting the PKCS#12 bundle (PFX file).
        :param pulumi.Input[str] certificate_expiry: The expiry time of the certificate.
        :param pulumi.Input[str] certificate_thumbprint: The thumbprint of the certificate.
        :param pulumi.Input[bool] external_access_enabled: Whether to enable external access to LDAPS over the Internet. Defaults to `false`.
        :param pulumi.Input[str] public_certificate: The public certificate.
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "pfx_certificate", pfx_certificate)
        pulumi.set(__self__, "pfx_certificate_password", pfx_certificate_password)
        if certificate_expiry is not None:
            pulumi.set(__self__, "certificate_expiry", certificate_expiry)
        if certificate_thumbprint is not None:
            pulumi.set(__self__, "certificate_thumbprint", certificate_thumbprint)
        if external_access_enabled is not None:
            pulumi.set(__self__, "external_access_enabled", external_access_enabled)
        if public_certificate is not None:
            pulumi.set(__self__, "public_certificate", public_certificate)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[bool]:
        """
        Whether to enable secure LDAP for the managed domain. For more information, please see [official documentation on enabling LDAPS](https://docs.microsoft.com/azure/active-directory-domain-services/tutorial-configure-ldaps), paying particular attention to the section on network security to avoid unnecessarily exposing your service to Internet-borne bruteforce attacks.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[bool]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="pfxCertificate")
    def pfx_certificate(self) -> pulumi.Input[str]:
        """
        The certificate/private key to use for LDAPS, as a base64-encoded TripleDES-SHA1 encrypted PKCS#12 bundle (PFX file).
        """
        return pulumi.get(self, "pfx_certificate")

    @pfx_certificate.setter
    def pfx_certificate(self, value: pulumi.Input[str]):
        pulumi.set(self, "pfx_certificate", value)

    @property
    @pulumi.getter(name="pfxCertificatePassword")
    def pfx_certificate_password(self) -> pulumi.Input[str]:
        """
        The password to use for decrypting the PKCS#12 bundle (PFX file).
        """
        return pulumi.get(self, "pfx_certificate_password")

    @pfx_certificate_password.setter
    def pfx_certificate_password(self, value: pulumi.Input[str]):
        pulumi.set(self, "pfx_certificate_password", value)

    @property
    @pulumi.getter(name="certificateExpiry")
    def certificate_expiry(self) -> Optional[pulumi.Input[str]]:
        """
        The expiry time of the certificate.
        """
        return pulumi.get(self, "certificate_expiry")

    @certificate_expiry.setter
    def certificate_expiry(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "certificate_expiry", value)

    @property
    @pulumi.getter(name="certificateThumbprint")
    def certificate_thumbprint(self) -> Optional[pulumi.Input[str]]:
        """
        The thumbprint of the certificate.
        """
        return pulumi.get(self, "certificate_thumbprint")

    @certificate_thumbprint.setter
    def certificate_thumbprint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "certificate_thumbprint", value)

    @property
    @pulumi.getter(name="externalAccessEnabled")
    def external_access_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable external access to LDAPS over the Internet. Defaults to `false`.
        """
        return pulumi.get(self, "external_access_enabled")

    @external_access_enabled.setter
    def external_access_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "external_access_enabled", value)

    @property
    @pulumi.getter(name="publicCertificate")
    def public_certificate(self) -> Optional[pulumi.Input[str]]:
        """
        The public certificate.
        """
        return pulumi.get(self, "public_certificate")

    @public_certificate.setter
    def public_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "public_certificate", value)


if not MYPY:
    class ServiceSecurityArgsDict(TypedDict):
        kerberos_armoring_enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether to enable Kerberos Armoring. Defaults to `false`.
        """
        kerberos_rc4_encryption_enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether to enable Kerberos RC4 Encryption. Defaults to `false`.
        """
        ntlm_v1_enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether to enable legacy NTLM v1 support. Defaults to `false`.
        """
        sync_kerberos_passwords: NotRequired[pulumi.Input[bool]]
        """
        Whether to synchronize Kerberos password hashes to the managed domain. Defaults to `false`.
        """
        sync_ntlm_passwords: NotRequired[pulumi.Input[bool]]
        """
        Whether to synchronize NTLM password hashes to the managed domain. Defaults to `false`.
        """
        sync_on_prem_passwords: NotRequired[pulumi.Input[bool]]
        """
        Whether to synchronize on-premises password hashes to the managed domain. Defaults to `false`.
        """
        tls_v1_enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether to enable legacy TLS v1 support. Defaults to `false`.
        """
elif False:
    ServiceSecurityArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceSecurityArgs:
    def __init__(__self__, *,
                 kerberos_armoring_enabled: Optional[pulumi.Input[bool]] = None,
                 kerberos_rc4_encryption_enabled: Optional[pulumi.Input[bool]] = None,
                 ntlm_v1_enabled: Optional[pulumi.Input[bool]] = None,
                 sync_kerberos_passwords: Optional[pulumi.Input[bool]] = None,
                 sync_ntlm_passwords: Optional[pulumi.Input[bool]] = None,
                 sync_on_prem_passwords: Optional[pulumi.Input[bool]] = None,
                 tls_v1_enabled: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[bool] kerberos_armoring_enabled: Whether to enable Kerberos Armoring. Defaults to `false`.
        :param pulumi.Input[bool] kerberos_rc4_encryption_enabled: Whether to enable Kerberos RC4 Encryption. Defaults to `false`.
        :param pulumi.Input[bool] ntlm_v1_enabled: Whether to enable legacy NTLM v1 support. Defaults to `false`.
        :param pulumi.Input[bool] sync_kerberos_passwords: Whether to synchronize Kerberos password hashes to the managed domain. Defaults to `false`.
        :param pulumi.Input[bool] sync_ntlm_passwords: Whether to synchronize NTLM password hashes to the managed domain. Defaults to `false`.
        :param pulumi.Input[bool] sync_on_prem_passwords: Whether to synchronize on-premises password hashes to the managed domain. Defaults to `false`.
        :param pulumi.Input[bool] tls_v1_enabled: Whether to enable legacy TLS v1 support. Defaults to `false`.
        """
        if kerberos_armoring_enabled is not None:
            pulumi.set(__self__, "kerberos_armoring_enabled", kerberos_armoring_enabled)
        if kerberos_rc4_encryption_enabled is not None:
            pulumi.set(__self__, "kerberos_rc4_encryption_enabled", kerberos_rc4_encryption_enabled)
        if ntlm_v1_enabled is not None:
            pulumi.set(__self__, "ntlm_v1_enabled", ntlm_v1_enabled)
        if sync_kerberos_passwords is not None:
            pulumi.set(__self__, "sync_kerberos_passwords", sync_kerberos_passwords)
        if sync_ntlm_passwords is not None:
            pulumi.set(__self__, "sync_ntlm_passwords", sync_ntlm_passwords)
        if sync_on_prem_passwords is not None:
            pulumi.set(__self__, "sync_on_prem_passwords", sync_on_prem_passwords)
        if tls_v1_enabled is not None:
            pulumi.set(__self__, "tls_v1_enabled", tls_v1_enabled)

    @property
    @pulumi.getter(name="kerberosArmoringEnabled")
    def kerberos_armoring_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable Kerberos Armoring. Defaults to `false`.
        """
        return pulumi.get(self, "kerberos_armoring_enabled")

    @kerberos_armoring_enabled.setter
    def kerberos_armoring_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "kerberos_armoring_enabled", value)

    @property
    @pulumi.getter(name="kerberosRc4EncryptionEnabled")
    def kerberos_rc4_encryption_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable Kerberos RC4 Encryption. Defaults to `false`.
        """
        return pulumi.get(self, "kerberos_rc4_encryption_enabled")

    @kerberos_rc4_encryption_enabled.setter
    def kerberos_rc4_encryption_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "kerberos_rc4_encryption_enabled", value)

    @property
    @pulumi.getter(name="ntlmV1Enabled")
    def ntlm_v1_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable legacy NTLM v1 support. Defaults to `false`.
        """
        return pulumi.get(self, "ntlm_v1_enabled")

    @ntlm_v1_enabled.setter
    def ntlm_v1_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ntlm_v1_enabled", value)

    @property
    @pulumi.getter(name="syncKerberosPasswords")
    def sync_kerberos_passwords(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to synchronize Kerberos password hashes to the managed domain. Defaults to `false`.
        """
        return pulumi.get(self, "sync_kerberos_passwords")

    @sync_kerberos_passwords.setter
    def sync_kerberos_passwords(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sync_kerberos_passwords", value)

    @property
    @pulumi.getter(name="syncNtlmPasswords")
    def sync_ntlm_passwords(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to synchronize NTLM password hashes to the managed domain. Defaults to `false`.
        """
        return pulumi.get(self, "sync_ntlm_passwords")

    @sync_ntlm_passwords.setter
    def sync_ntlm_passwords(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sync_ntlm_passwords", value)

    @property
    @pulumi.getter(name="syncOnPremPasswords")
    def sync_on_prem_passwords(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to synchronize on-premises password hashes to the managed domain. Defaults to `false`.
        """
        return pulumi.get(self, "sync_on_prem_passwords")

    @sync_on_prem_passwords.setter
    def sync_on_prem_passwords(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sync_on_prem_passwords", value)

    @property
    @pulumi.getter(name="tlsV1Enabled")
    def tls_v1_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable legacy TLS v1 support. Defaults to `false`.
        """
        return pulumi.get(self, "tls_v1_enabled")

    @tls_v1_enabled.setter
    def tls_v1_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "tls_v1_enabled", value)


